import 'package:cpt_sg/modules/agency/contract_add/contract_add_page.dart';
import 'package:cpt_sg/modules/agency/contract_rate_list/contract_rate_list_page.dart';
import 'package:domain/entity/response/labour_request_s_g_list_entity.dart';
import 'package:domain/repository/labour_sg_repository.dart';

import 'package:domain/entity/response/labour_request_index_entity.dart';
import 'package:get/get.dart';
import 'package:plugin_platform/engine/toast/toast_engine.dart';
import 'package:plugin_platform/http/dio/dio_cancelable_mixin.dart';
import 'package:plugin_platform/http/http_result.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/widget_export.dart';
import 'contract_list_state.dart';

class ContractListController extends GetxController with DioCancelableMixin {
  final LabourSGRepository _labourRepository = Get.find();
  final ContractListState state = ContractListState();

  var _curPage = 1;
  var _needShowPlaceholder = true;

  //页面PlaceHolder的展示
  LoadState loadingState = LoadState.State_Success;
  String? errorMessage;

  //刷新页面状态
  void changeLoadingState(LoadState state) {
    loadingState = state;
    update();
  }

  // Refresh 控制器
  final EasyRefreshController refreshController = EasyRefreshController(
    controlFinishRefresh: true,
    controlFinishLoad: true,
  );

  // Refresh 刷新事件
  Future onRefresh() async {
    _curPage = 1;
    fetchLabourRequestList();
  }

  // Refresh 加载事件
  Future loadMore() async {
    _curPage++;
    fetchLabourRequestList();
  }

  // 重试请求
  Future retryRequest() async {
    _curPage = 1;
    _needShowPlaceholder = true;
    fetchLabourRequestList();
  }

  /// 获取列表数据
  Future fetchLabourRequestList() async {
    if (_needShowPlaceholder) {
      changeLoadingState(LoadState.State_Loading);
    }

    // 并发执行两个请求
    var futures = [
      _labourRepository.fetchLabourRequestSGList(
        state.keyword,
        "",
        "",
        state.selectedStatusId,
        "",
        curPage: _curPage,
        cancelToken: cancelToken,
      ),
      state.indexOptions == null
          ? _labourRepository.fetchLabourRequestSGIndex(
              cancelToken: cancelToken,
            )
          : Future(() => HttpResult(isSuccess: true).convert(data: state.indexOptions!)),
    ];

    //拿到结果
    var results = await Future.wait(futures);
    var listResult = results[0] as HttpResult<LabourRequestSGListEntity>;
    var optionResult = results[1] as HttpResult<LabourRequestIndexEntity>;

    //选项数据
    if (state.indexOptions == null && optionResult.isSuccess) {
      state.indexOptions = optionResult.data!;
    }

    // 处理数据
    if (listResult.isSuccess) {
      handleList(listResult.data?.rows);
    } else {
      errorMessage = listResult.errorMsg;
      changeLoadingState(LoadState.State_Error);
    }

    // 最后赋值
    _needShowPlaceholder = false;
  }

  // 处理数据与展示的逻辑
  void handleList(List<LabourRequestSGListRows>? list) {
    if (list != null && list.isNotEmpty) {
      //有数据，判断是刷新还是加载更多的数据
      if (_curPage == 1) {
        //刷新的方式
        state.datas.clear();
        state.datas.addAll(list);
        refreshController.finishRefresh();

        //更新展示的状态
        changeLoadingState(LoadState.State_Success);
      } else {
        //加载更多
        state.datas.addAll(list);
        refreshController.finishLoad();
        update();
      }
    } else {
      if (_curPage == 1) {
        //展示无数据的布局
        state.datas.clear();
        changeLoadingState(LoadState.State_Empty);
        refreshController.finishRefresh();
      } else {
        //展示加载完成，没有更多数据了
        refreshController.finishLoad(IndicatorResult.noMore);
      }
    }
  }

  // 执行搜索
  void doSearch(String keyword) {
    state.keyword = keyword;
    //赋值之后刷新
    refreshController.callRefresh();
  }

  // 清空搜索条件
  void resetFiltering() {
    state.keyword = "";
    state.searchController.text = "";
    state.selectedStatusId = null;

    //赋值之后刷新
    refreshController.callRefresh();
  }

  /// 根据ID获取Item对象，用于刷新
  void fetchItemByIdAndRefreshItem(String requestId) async {
    var result = await _labourRepository.fetchItemByRequestId(
      requestId,
      cancelToken: cancelToken,
    );

    //处理数据
    if (result.isSuccess) {
      var data = result.data;
      if (data != null && data.rows != null && data.rows!.isNotEmpty) {
        final requestItem = data.rows![0];

        //找到当前数据中的此 requestId，并替换对象，再刷新
        var index = state.datas.indexWhere((element) => element.requestId == requestItem.requestId);
        if (index >= 0) {
          state.datas[index] = requestItem;
          update();
        }
      }
    } else {
      ToastEngine.show(result.errorMsg ?? "Network Load Error".tr);
    }
  }

  @override
  void onReady() {
    super.onReady();
    fetchLabourRequestList();
  }

  @override
  void onClose() {
    state.datas.clear();
    super.onClose();
  }

  //跳转到添加页面
  void gotoAddPage() {
    SGContractAddPage.startInstance("", (result) {
      if (result != null) {
        refreshController.callRefresh();
      }
    });
  }

  //去详情页面
  void gotoDetailPage(LabourRequestSGListRows data) {
    SGContractRateListPage.startInstance();
  }

  //去编辑页面
  void gotoEditPage(LabourRequestSGListRows data) {
    SGContractAddPage.startInstance("123", (result) {
      if (result != null) {
        fetchItemByIdAndRefreshItem(data.requestId.toString());
      }
    });
  }
  /// 选择状态
  void pickStatus() {}

  /// 选择中介
  void pickAgency() {

  }

}
