import 'package:domain/entity/response/labour_request_s_g_list_entity.dart';
import 'package:domain/repository/labour_sg_repository.dart';
import 'package:get/get.dart';
import 'package:plugin_platform/engine/dialog/dialog_engine.dart';
import 'package:plugin_platform/engine/notify/notify_engine.dart';
import 'package:plugin_platform/engine/toast/toast_engine.dart';
import 'package:plugin_platform/http/dio/dio_cancelable_mixin.dart';
import 'package:widgets/dialog/app_default_dialog.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/widget_export.dart';

import '../contract_rate_setting/contract_rate_setting_page.dart';
import '../contract_rate_specific_day/contract_rate_specific_page.dart';
import 'contract_rate_edit_list_state.dart';
import 'dialog/dialog_edit_rate.dart';

class ContractRateEditListController extends GetxController with DioCancelableMixin {
  final LabourSGRepository _labourRepository = Get.find();
  final ContractRateEditListState state = ContractRateEditListState();

  var _curPage = 1;
  var _needShowPlaceholder = true;

  //页面PlaceHolder的展示
  LoadState loadingState = LoadState.State_Success;
  String? errorMessage;

  //刷新页面状态
  void changeLoadingState(LoadState state) {
    loadingState = state;
    update();
  }

  // Refresh 控制器
  final EasyRefreshController refreshController = EasyRefreshController(
    controlFinishRefresh: true,
    controlFinishLoad: true,
  );

  // Refresh 刷新事件
  Future onRefresh() async {
    _curPage = 1;
    fetchLabourRequestList();
  }

  // Refresh 加载事件
  Future loadMore() async {
    _curPage++;
    fetchLabourRequestList();
  }

  // 重试请求
  Future retryRequest() async {
    _curPage = 1;
    _needShowPlaceholder = true;
    fetchLabourRequestList();
  }

  /// 获取列表数据
  Future fetchLabourRequestList() async {
    if (_needShowPlaceholder) {
      changeLoadingState(LoadState.State_Loading);
    }

    // 并发执行两个请求

    var listResult = await _labourRepository.fetchLabourRequestSGList(
      "",
      "",
      "",
      "",
      "",
      curPage: _curPage,
      cancelToken: cancelToken,
    );

    // 处理数据
    if (listResult.isSuccess) {
      handleList(listResult.data?.rows);
    } else {
      errorMessage = listResult.errorMsg;
      changeLoadingState(LoadState.State_Error);
    }

    // 最后赋值
    _needShowPlaceholder = false;
  }

  // 处理数据与展示的逻辑
  void handleList(List<LabourRequestSGListRows>? list) {
    if (list != null && list.isNotEmpty) {
      //有数据，判断是刷新还是加载更多的数据
      if (_curPage == 1) {
        //刷新的方式
        state.datas.clear();
        state.datas.addAll(list);
        refreshController.finishRefresh();

        //更新展示的状态
        changeLoadingState(LoadState.State_Success);
      } else {
        //加载更多
        state.datas.addAll(list);
        refreshController.finishLoad();
        update();
      }
    } else {
      if (_curPage == 1) {
        //展示无数据的布局
        state.datas.clear();
        changeLoadingState(LoadState.State_Empty);
        refreshController.finishRefresh();
      } else {
        //展示加载完成，没有更多数据了
        refreshController.finishLoad(IndicatorResult.noMore);
      }
    }
  }


  @override
  void onReady() {
    super.onReady();
    fetchLabourRequestList();
  }

  @override
  void onClose() {
    state.datas.clear();
    super.onClose();
  }

  //去详情页面
  void gotoSettingPage() {
    ContractRateSettingPage.startInstance("123", (result) {

    });
  }

  //去设置特殊的日期
  void gotoAddSpecificPage() {
    SGContractRateSpecificPage.startInstance((result){

    });
  }

  /// 展示这个日期的编辑弹窗
  void showEditDialog(LabourRequestSGListRows data) {

    DialogEngine.show(
      widget: EditRateDialog(
        rate:"10",
        confirmAction: (rate) {
         ToastEngine.show("输入的时薪为：$rate");
        },
      ),
    );

  }

  /// 删除的确认弹窗
  void showDeleteDialog(LabourRequestSGListRows data,int index) {
    DialogEngine.show(
        widget: AppDefaultDialog(
          title: "Confirmation".tr,
          message: "Are you sure you want to delete this Rate?".tr,
          confirmAction: () {
            _submitDeleteRequest(data.requestId.toString(),index);
          },
        ));
  }

  void _submitDeleteRequest(String? requestId, int index) async {
    var result = await _labourRepository.deleteLabourRequestSG(requestId, cancelToken: cancelToken);

    if (result.isSuccess) {
      NotifyEngine.showSuccess("Successful".tr);

      if (state.datas.length <= 1) {
        refreshController.callRefresh();
      } else {
        state.datas.removeAt(index);
        update();
      }
    } else {
      ToastEngine.show(result.errorMsg ?? "Network Load Error".tr);
    }
  }

}
